from distutils.core import setup

setup(
    name= 'nesternits1991',
    version = '1.0.0',
    py_modules = ['nester'],
    author = 'hfpython',
    author_email = 'agg@gmail.com',
    url = 'http://nitin.com',
    description = 'a simple list printer',
)